-- Novell Secure Password Manager Schema Definitions
-- Novell Inc.
-- 1800 South Novell Place
-- Provo, UT 84606
--
-- Copyright=(c) Copyright 2003, Novell, Inc.  All rights reserved
--
-- Object ID (OID) is registered with Internal Schema Registration
-- as of 15 Jan 1997.
--
-- OIDs Defined as Follows:
--   joint-iso-ccitt(2) country(16) us(840) organization(1)
--   Novell(113719) applications(1) SAS(39) NSIM(44)
--                                          NSPMAttributeType(4) attr#
--                                          NSPMObjectClass(6)   class#

NSIMSchemaExtentions DEFINITIONS ::=
BEGIN

-- -- -- -- -- -- -- -- -- -- -- -- --
-- Challenge Set attributes
-- -- -- -- -- -- -- -- -- -- -- -- --

-- Required questions. This is xml data defining the required questions that
-- will be presented to the user to answer.  A question can be admin defined or
-- user defined.  All these questions will have to be answered.
    "nsimRequiredQuestions" ATTRIBUTE ::=
    {
        Operation	 ADD,
        SyntaxID	 SYN_CE_STRING,
        Flags		 {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID	 {2 16 840 1 113719 1 39 44 4 1}
    }

-- Random questions. This is xml data defining the random questions that
-- will be presented to the user to answer. A question can be admin defined or
-- user defined. All these questions will have to be initially answered, but not all asked.
    "nsimRandomQuestions" ATTRIBUTE ::=
    {
        Operation	 ADD,
        SyntaxID	 SYN_CE_STRING,
        Flags		 {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID	 {2 16 840 1 113719 1 39 44 4 2}
    }

-- Number of Random questions.  The number of random questions that will be
-- presented to the user to answer.
    "nsimNumberRandomQuestions" ATTRIBUTE ::=
    {
        Operation	 ADD,
        SyntaxID	 SYN_INTEGER,
        Flags		 {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID	 {2 16 840 1 113719 1 39 44 4 3}
    }

-- Minimum length response.  The minimum length of the response from the user.
    "nsimMinResponseLength" ATTRIBUTE ::=
    {
        Operation	 ADD,
        SyntaxID	 SYN_INTEGER,
        Flags		 {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID	 {2 16 840 1 113719 1 39 44 4 4}
    }

-- Maximum length response.  The maximum length of the response from the user.
    "nsimMaxResponseLength" ATTRIBUTE ::=
    {
        Operation	 ADD,
        SyntaxID	 SYN_INTEGER,
        Flags		 {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID	 {2 16 840 1 113719 1 39 44 4 5}
    }


-- -- -- -- -- -- -- -- -- -- -- -- --
-- Password Policy Attributes
-- -- -- -- -- -- -- -- -- -- -- -- --

-- Forgotten Login Config.  Tells the application to auto setup the
-- Challenge/Response or Hint when the user logs in for the first time.
    "nsimForgottenLoginConfig" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_BOOLEAN,
        Flags        {DS_SINGLE_VALUED_ATTR},
        ASN1ObjID    {2 16 840 1 113719 1 39 44 4 6}
    }

-- The Forgotten Password Action. This is xml data defining what action occurs
-- when the user selects the forgot password link, it also specifies whether
-- authentication is need or not for this action.
    "nsimForgottenAction" ATTRIBUTE ::=
    {
 	Operation	ADD,
 	SyntaxID	SYN_CE_STRING,
 	Flags	 	{DS_SINGLE_VALUED_ATTR},
 	ASN1ObjID	{2 16 840 1 113719 1 39 44 4 7}
    }

-- Assignment list.  This will help provide an easy way to access the
-- assignments of the policy without having to search the entire tree for the
-- assignments.
    "nsimAssignments" ATTRIBUTE ::=
     {
 	Operation	ADD,
 	SyntaxID	SYN_DIST_NAME,
 	ASN1ObjID	{2 16 840 1 113719 1 39 44 4 8}
     }

-- Attribute on the Password Policy object that specifies the
-- defined challenge set for this object
     "nsimChallengeSetDN" ATTRIBUTE ::=
     {
 	Operation	ADD,
 	SyntaxID	SYN_DIST_NAME,
 	Flags		{DS_SINGLE_VALUED_ATTR},
 	ASN1ObjID	{2 16 840 1 113719 1 39 44 4 9}
    }

-- Attribute on the Password Policy object that specifies a
-- unique ID to determine when the policy is out of sync or modified
    "nsimChallengeSetGUID" ATTRIBUTE ::=
    {
 	Operation	ADD,
 	SyntaxID	SYN_CE_STRING,
 	Flags		{DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR},
 	ASN1ObjID	{2 16 840 1 113719 1 39 44 4 10}
    }

-- Attribute on the Password Policy object that tells the
-- application to enforce the password policy upon authentication
    "nsimPwdRuleEnforcement" ATTRIBUTE ::=
     {
 	Operation	ADD,
 	SyntaxID	SYN_BOOLEAN,
 	Flags		{DS_SINGLE_VALUED_ATTR},
 	ASN1ObjID	{2 16 840 1 113719 1 39 44 4 11}
    }

-- -- -- -- -- -- -- -- -- -- -- -- --
-- User Attributes
-- -- -- -- -- -- -- -- -- -- -- -- --

-- Users Hint to help them remember their password
    "nsimHint" ATTRIBUTE ::=
    {
        Operation    ADD,
        SyntaxID     SYN_CE_STRING,
        Flags        {DS_PUBLIC_READ, DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
        ASN1ObjID    {2 16 840 1 113719 1 39 44 4 12}
    }

-- ------------------------------------
-- Class Definition of Challenge Set
-- ------------------------------------

   "nsimChallengeSet" OBJECT-CLASS ::=
    {
        Operation    ADD,
        Flags        {DS_EFFECTIVE_CLASS},
        SubClassOf   {"Top"},
        ContainedBy  {"nspmPasswordPolicyContainer"},
        NamedBy      {"CN"},
        MustContain  {"CN"},
        MayContain   {"Description",
		         "nsimRequiredQuestions",
		         "nsimRandomQuestions",
		         "nsimNumberRandomQuestions",
		         "nsimMinResponseLength",
		         "nsimMaxResponseLength"
					 },
    	ASN1ObjID    {2 16 840 1 113719 1 39 44 6 1}
    }

-- --------------------------------
-- Modification of Existing Classes
-- --------------------------------

    "ndsLoginProperties" OBJECT-CLASS ::=
     {
	Operation	MODIFY,
	MayContain	{
				"nsimHint"
  			    }
     }

    "nspmPasswordPolicy" OBJECT-CLASS ::=
    {
	Operation	MODIFY,
	MayContain	{
				"nsimChallengeSetDN",
				"nsimForgottenAction",
				"nsimForgottenLoginConfig",
				"nsimAssignments",
				"nsimChallengeSetGUID",
				"nsimPwdRuleEnforcement"
			}
    }

END

